Request Rest API — Rucio 1.2 documentation

# Request Rest API

Overview

Resource | Operation | Description
--- | --- | ---
RequestGet | GET /requests/(scope)/(name)/(rse) | list requests

Details

`GET` `/requests/`(scope)`/`(name)`/`(rse)

  List request for given DID to a destination RSE.

  Parameters: | scope – data identifier scope. name – data identifier name. rse – destination RSE.
  Request Headers:
  | Content-Type – application/json
  Status Codes: | 200 OK – Request found. 404 Not Found – Request not found.